Learn R Programming

MolgenisArmadillo (version 2.9.3)

.get_linkfile_content: Helper function to get the contents of a linkfile

Description

Helper function to get the contents of a linkfile

Usage

.get_linkfile_content(project, object_name)

Value

the contents of the linkfile

Arguments

project

projectname where the linkfile is stored

object_name

folder/name of linkfile