Learn R Programming

MolgenisArmadillo (version 2.9.3)

armadillo.delete_project: Delete project

Description

A project represents usually a study or collection of variables

Usage

armadillo.delete_project(project_name)

Arguments

project_name

the name of the study or collection of variables name

Examples

Run this code
if (FALSE) {
armadillo.delete_project(project_name = "gecko")
}

Run the code above in your browser using DataLab