Learn R Programming

MolgenisArmadillo (version 2.9.3)

armadillo.login: Login

Description

Interactively obtains an id token and uses it to create a session token for an Armadillo Service

Usage

armadillo.login(armadillo)

Value

the id token

Arguments

armadillo

URL of the Armadillo server,

Examples

Run this code
if (FALSE) {
armadillo.login(
  "https://armadillo.dev.molgenis.org"
)
armadillo.login("http://localhost:8080")
}

Run the code above in your browser using DataLab