This automates the process of:
Checking what data is available to create subsets
Make the subset
armadillo.subset(
input_source = NULL,
subset_def = NULL,
source_project = NULL,
source_folder = NULL,
source_table = NULL,
target_project = NULL,
target_folder = NULL,
target_table = NULL,
target_vars = NULL,
new_project = NULL,
dry_run = NULL,
strict = FALSE
)missing variables provided in the subset definition
Character specifying how information about the target view is provided: choose 'subset_def' if providing a subset definition object, or 'arguments' if providing information directly.
R object containing subset definition created by
armadillo.subset_definition(). Compulsory if input_source = 'subset_def'
project from which to subset data
folder from which to subset data. Compulsory if input_source = 'arguments'.
table from which to subset data. Compulsory if input_source = 'arguments'.
project to upload subset to. Will be created if it doesn't exist.
folder to upload subset to. Will be created if it doesn't exist. Compulsory if input_source = 'arguments'.
table to upload subset to. Compulsory if input_source = 'arguments'.
variables from `source_table` to include in the view. Compulsory if input_source = 'arguments'.
Deprecated: use target_project instead
Defunct: previously enabgled dry-run to check which variables are missing
Boolean specifying whether to create subset if one or more target variables do not exist in the target data. Option FALSE will throw and error, option TRUE (default) creates subset and return a warning
if (FALSE) {
armadillo.subset(
source_project = "gecko",
target_project = "study1",
subset_def = local_subset
)
}
Run the code above in your browser using DataLab