.add_slash_if_missing: Add a Slash to a URL if Missing
Description
This function ensures that a given URL string ends with a slash ('/').
If the URL does not end with a slash, it appends one.
Usage
.add_slash_if_missing(url)
Value
A character string with a trailing slash if it was missing.
Arguments
- url
A character string representing the URL.