.load_linked_table: Helper function to extract the source parquet file in a linkfile
Description
Helper function to extract the source parquet file in a linkfile
Usage
.load_linked_table(file, columns)
Value
the contents of the file, as data frame
Arguments
- file
source table parquet file
- columns
character list of columns to select from source file