powered by
A project represents usually a study or collection of variables
armadillo.delete_project(project_name)
the name of the study or collection of variables name
if (FALSE) { armadillo.delete_project(project_name = "gecko") }
Run the code above in your browser using DataLab