powered by
Interactively obtains an id token and uses it to create a session token for an Armadillo Service
armadillo.login(armadillo)
the id token
URL of the Armadillo server,
if (FALSE) { armadillo.login( "https://armadillo.dev.molgenis.org" ) armadillo.login("http://localhost:8080") }
Run the code above in your browser using DataLab